@@ -615,7 +615,12 @@ def unique_project_name(filename):
 	project_list=get_local_project_list()
 
 	big_name=generate_slug().split("-")
-	name=filename.split(".")[0].replace("_","-").replace("_", " ").lower()+ "-" + big_name[random.randint(0,len(big_name)-1)]
+	filteredName = big_name[random.randint(0,len(big_name)-1)]
+
+	if len(filteredName)<4:
+		return unique_project_name(filename)
+
+	name=filename.split(".")[0].replace("_","-").replace("_", " ").lower()+ "-" + filteredName
 
 	if name in project_list:
 		return unique_project_name(filename)
